@@ -27,12 +27,19 @@ except ImportError:
 class ClientException(BaseException):
     pass
 
+API_HOST = 'https://nucleo.arcus.io/api/v1'
+
+def _request(path='', method='get', data=None, api_key=None, params={}):
+    data = utils.api_request(API_HOST, path, method=method, \
+        data=data, api_key=api_key, params={})
+    return data
+
 class Client(object):
     """
     Arcus Client
 
     """
-    def __init__(self, username=None, password=None, host='https://nucleo.arcus.io/api/v1', \
+    def __init__(self, username=None, password=None, host=API_HOST, \
         api_key=None):
         self._host = host
         self._username = username
@@ -42,11 +49,19 @@ class Client(object):
         if self._username and self._password:
             self._login()
 
-    def _request(self, path='', method='get', data=None, params={}):
-        data = utils.api_request(self._host, path, method=method, \
-            data=data, api_key=self._api_key, params={})
+    @classmethod
+    def login(cls, username=None, password=None,
+        host='https://nucleo.arcus.io/api/v1'):
+        user_data = {'username': username, 'password': password}
+        resp = _request('/login', method='post', data=user_data)
+        data = {}
+        try:
+            data = json.loads(resp.content)
+        except:
+            pass
         return data
 
+        
     def _login(self):
         """
         Logs in
@@ -54,11 +69,10 @@ class Client(object):
         :returns: User data as dict
 
         """
-        user_data = {'username': self._username, 'password': self._password}
-        data = self._request('/login', method='post', data=user_data)
-        if data.status_code == 200:
+        data = self.login(self._username, self._password)
+        if data.get('status_code') == 200:
             self._logged_in = True
-            self._api_key = data.json.get('meta', {}).get('api_key')
+            self._api_key = data.get('meta', {}).get('api_key')
         else:
             raise ClientException(data.content)
 
@@ -69,7 +83,7 @@ class Client(object):
         :returns: Applications as dict
 
         """
-        data = self._request(path='/apps', method='get')
+        data = _request(path='/apps', method='get', api_key=self._api_key)
         if data.status_code == 200:
             return data
         else:
@@ -82,7 +96,8 @@ class Client(object):
         :returns: Application data as dict
 
         """
-        data = self._request('/apps/{0}'.format(name), method='get')
+        data = _request('/apps/{0}'.format(name), method='get',
+            api_key=self._api_key)
         if data.status_code == 200:
             return data
         else:
@@ -95,7 +110,8 @@ class Client(object):
         :returns: Application statistics as dict
 
         """
-        data = self._request('/apps/{0}/stats'.format(name), method='get')
+        data = _request('/apps/{0}/stats'.format(name), method='get',
+            api_key=self._api_key)
         if data.status_code == 200:
             return data
         else:
@@ -108,8 +124,8 @@ class Client(object):
         """
         node_name = socket.gethostname()
         # call puppet to register
-        data = self._request('/nodes/register', method='post', \
-            data={'node_name': node_name})
+        data = _request('/nodes/register', method='post', \
+            data={'node_name': node_name}, api_key=self._api_key)
         if data.status_code == 200:
             data = json.loads(data.content)
             puppet_master = data.get('puppet_master')
